==> apiextractor_0.8.0-1maemo1.tar.gz: apiextractor-0.8.0/obj-i486-linux-gnu/qrc_generator.cxx <==
/****************************************************************************
** Resource object code
**
** Created: Tue Sep 14 18:57:39 2010
**      by: The Resource Compiler for Qt version 4.6.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /home/willer/upload/apiextractor/build/apiextractor-0.8.0/parser/rpp/pp-qt-configuration
  0x0,0x0,0x1,0xdc,
  0x23,
  0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x5f,0x5f,0x63,0x70,0x6c,0x75,0x73,0x70,0x6c,
  0x75,0x73,0x20,0x31,0xa,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x5f,0x5f,
  0x53,0x54,0x44,0x43,0x5f,0x5f,0xa,0xa,0x2f,0x2f,0x20,0x51,0x74,0xa,0x23,0x64,
  0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x4f,0x42,0x4a,0x45,0x43,0x54,0x44,0x45,0x46,
  0x53,0x5f,0x48,0xa,0xa,0x2f,0x2f,0x20,0x6e,0x6f,0x74,0x20,0x79,0x65,0x74,0x20,
  0x73,0x75,0x70,0x70,0x6f,0x72,0x74,0x65,0x64,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,
  0x65,0x20,0x51,0x5f,0x53,0x4c,0x4f,0x54,0x53,0x20,0x73,0x6c,0x6f,0x74,0x73,0xa,
  0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x5f,0x53,0x49,0x47,0x4e,0x41,0x4c,
  0x53,0x20,0x73,0x69,0x67,0x6e,0x61,0x6c,0x73,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,
  0x65,0x20,0x51,0x5f,0x46,0x4c,0x41,0x47,0x53,0x28,0x61,0x29,0xa,0x23,0x64,0x65,
  0x66,0x69,0x6e,0x65,0x20,0x51,0x5f,0x50,0x52,0x49,0x56,0x41,0x54,0x45,0x5f,0x53,
  0x4c,0x4f,0x54,0x28,0x61,0x2c,0x20,0x62,0x29,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,
  0x65,0x20,0x51,0x5f,0x44,0x45,0x43,0x4c,0x41,0x52,0x45,0x5f,0x49,0x4e,0x54,0x45,
  0x52,0x46,0x41,0x43,0x45,0x28,0x61,0x2c,0x62,0x29,0xa,0x23,0x64,0x65,0x66,0x69,
  0x6e,0x65,0x20,0x51,0x5f,0x49,0x4e,0x54,0x45,0x52,0x46,0x41,0x43,0x45,0x53,0x28,
  0x61,0x29,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x5f,0x47,0x41,0x44,
  0x47,0x45,0x54,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x5f,0x4f,0x56,
  0x45,0x52,0x52,0x49,0x44,0x45,0x28,0x61,0x29,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,
  0x65,0x20,0x51,0x5f,0x4f,0x53,0x5f,0x4f,0x53,0x32,0xa,0x23,0x64,0x65,0x66,0x69,
  0x6e,0x65,0x20,0x51,0x5f,0x4e,0x4f,0x5f,0x55,0x53,0x49,0x4e,0x47,0x5f,0x4b,0x45,
  0x59,0x57,0x4f,0x52,0x44,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x54,
  0x5f,0x4e,0x4f,0x5f,0x51,0x4f,0x42,0x4a,0x45,0x43,0x54,0x5f,0x43,0x48,0x45,0x43,
  0x4b,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x54,0x5f,0x4e,0x4f,0x5f,
  0x4d,0x45,0x4d,0x42,0x45,0x52,0x5f,0x54,0x45,0x4d,0x50,0x4c,0x41,0x54,0x45,0x53,
  0xa,0x2f,0x2f,0x20,0x54,0x68,0x65,0x72,0x65,0x20,0x61,0x72,0x65,0x20,0x73,0x79,
  0x6d,0x62,0x6f,0x6c,0x73,0x20,0x69,0x6e,0x20,0x51,0x74,0x20,0x74,0x68,0x61,0x74,
  0x20,0x65,0x78,0x69,0x73,0x74,0x20,0x69,0x6e,0x20,0x44,0x65,0x62,0x75,0x67,0x20,
  0x62,0x75,0x74,0xa,0x2f,0x2f,0x20,0x6e,0x6f,0x74,0x20,0x69,0x6e,0x20,0x72,0x65,
  0x6c,0x65,0x61,0x73,0x65,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x54,
  0x5f,0x4e,0x4f,0x5f,0x44,0x45,0x42,0x55,0x47,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // trolltech
  0x0,0x9,
  0x6,0x33,0x5c,0xb8,
  0x0,0x74,
  0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x6c,0x0,0x74,0x0,0x65,0x0,0x63,0x0,0x68,
    // generator
  0x0,0x9,
  0x4,0xc8,0x50,0xe2,
  0x0,0x67,
  0x0,0x65,0x0,0x6e,0x0,0x65,0x0,0x72,0x0,0x61,0x0,0x74,0x0,0x6f,0x0,0x72,
    // pp-qt-configuration
  0x0,0x13,
  0xc,0x13,0x30,0xfe,
  0x0,0x70,
  0x0,0x70,0x0,0x2d,0x0,0x71,0x0,0x74,0x0,0x2d,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x66,0x0,0x69,0x0,0x67,0x0,0x75,0x0,0x72,0x0,0x61,0x0,0x74,0x0,0x69,
  0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/trolltech
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/trolltech/generator
  0x0,0x0,0x0,0x18,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
  // :/trolltech/generator/pp-qt-configuration
  0x0,0x0,0x0,0x30,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_generator)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_generator))

int QT_MANGLE_NAMESPACE(qCleanupResources_generator)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_generator))

==> apiextractor_0.9.3-1maemo1.tar.gz: apiextractor-0.9.3/obj-i486-linux-gnu/qrc_generator.cxx <==
/****************************************************************************
** Resource object code
**
** Created: Fri Jan 28 15:20:30 2011
**      by: The Resource Compiler for Qt version 4.7.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /home/bruno/workspace/git/maemo5/apiextractor/parser/rpp/pp-qt-configuration
  0x0,0x0,0x1,0xdc,
  0x23,
  0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x5f,0x5f,0x63,0x70,0x6c,0x75,0x73,0x70,0x6c,
  0x75,0x73,0x20,0x31,0xa,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x5f,0x5f,
  0x53,0x54,0x44,0x43,0x5f,0x5f,0xa,0xa,0x2f,0x2f,0x20,0x51,0x74,0xa,0x23,0x64,
  0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x4f,0x42,0x4a,0x45,0x43,0x54,0x44,0x45,0x46,
  0x53,0x5f,0x48,0xa,0xa,0x2f,0x2f,0x20,0x6e,0x6f,0x74,0x20,0x79,0x65,0x74,0x20,
  0x73,0x75,0x70,0x70,0x6f,0x72,0x74,0x65,0x64,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,
  0x65,0x20,0x51,0x5f,0x53,0x4c,0x4f,0x54,0x53,0x20,0x73,0x6c,0x6f,0x74,0x73,0xa,
  0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x5f,0x53,0x49,0x47,0x4e,0x41,0x4c,
  0x53,0x20,0x73,0x69,0x67,0x6e,0x61,0x6c,0x73,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,
  0x65,0x20,0x51,0x5f,0x46,0x4c,0x41,0x47,0x53,0x28,0x61,0x29,0xa,0x23,0x64,0x65,
  0x66,0x69,0x6e,0x65,0x20,0x51,0x5f,0x50,0x52,0x49,0x56,0x41,0x54,0x45,0x5f,0x53,
  0x4c,0x4f,0x54,0x28,0x61,0x2c,0x20,0x62,0x29,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,
  0x65,0x20,0x51,0x5f,0x44,0x45,0x43,0x4c,0x41,0x52,0x45,0x5f,0x49,0x4e,0x54,0x45,
  0x52,0x46,0x41,0x43,0x45,0x28,0x61,0x2c,0x62,0x29,0xa,0x23,0x64,0x65,0x66,0x69,
  0x6e,0x65,0x20,0x51,0x5f,0x49,0x4e,0x54,0x45,0x52,0x46,0x41,0x43,0x45,0x53,0x28,
  0x61,0x29,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x5f,0x47,0x41,0x44,
  0x47,0x45,0x54,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x5f,0x4f,0x56,
  0x45,0x52,0x52,0x49,0x44,0x45,0x28,0x61,0x29,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,
  0x65,0x20,0x51,0x5f,0x4f,0x53,0x5f,0x4f,0x53,0x32,0xa,0x23,0x64,0x65,0x66,0x69,
  0x6e,0x65,0x20,0x51,0x5f,0x4e,0x4f,0x5f,0x55,0x53,0x49,0x4e,0x47,0x5f,0x4b,0x45,
  0x59,0x57,0x4f,0x52,0x44,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x54,
  0x5f,0x4e,0x4f,0x5f,0x51,0x4f,0x42,0x4a,0x45,0x43,0x54,0x5f,0x43,0x48,0x45,0x43,
  0x4b,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x54,0x5f,0x4e,0x4f,0x5f,
  0x4d,0x45,0x4d,0x42,0x45,0x52,0x5f,0x54,0x45,0x4d,0x50,0x4c,0x41,0x54,0x45,0x53,
  0xa,0x2f,0x2f,0x20,0x54,0x68,0x65,0x72,0x65,0x20,0x61,0x72,0x65,0x20,0x73,0x79,
  0x6d,0x62,0x6f,0x6c,0x73,0x20,0x69,0x6e,0x20,0x51,0x74,0x20,0x74,0x68,0x61,0x74,
  0x20,0x65,0x78,0x69,0x73,0x74,0x20,0x69,0x6e,0x20,0x44,0x65,0x62,0x75,0x67,0x20,
  0x62,0x75,0x74,0xa,0x2f,0x2f,0x20,0x6e,0x6f,0x74,0x20,0x69,0x6e,0x20,0x72,0x65,
  0x6c,0x65,0x61,0x73,0x65,0xa,0x23,0x64,0x65,0x66,0x69,0x6e,0x65,0x20,0x51,0x54,
  0x5f,0x4e,0x4f,0x5f,0x44,0x45,0x42,0x55,0x47,0xa,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // trolltech
  0x0,0x9,
  0x6,0x33,0x5c,0xb8,
  0x0,0x74,
  0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,0x6c,0x0,0x74,0x0,0x65,0x0,0x63,0x0,0x68,
    // generator
  0x0,0x9,
  0x4,0xc8,0x50,0xe2,
  0x0,0x67,
  0x0,0x65,0x0,0x6e,0x0,0x65,0x0,0x72,0x0,0x61,0x0,0x74,0x0,0x6f,0x0,0x72,
    // pp-qt-configuration
  0x0,0x13,
  0xc,0x13,0x30,0xfe,
  0x0,0x70,
  0x0,0x70,0x0,0x2d,0x0,0x71,0x0,0x74,0x0,0x2d,0x0,0x63,0x0,0x6f,0x0,0x6e,0x0,0x66,0x0,0x69,0x0,0x67,0x0,0x75,0x0,0x72,0x0,0x61,0x0,0x74,0x0,0x69,
  0x0,0x6f,0x0,0x6e,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/trolltech
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/trolltech/generator
  0x0,0x0,0x0,0x18,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
  // :/trolltech/generator/pp-qt-configuration
  0x0,0x0,0x0,0x30,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_generator)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_generator))

int QT_MANGLE_NAMESPACE(qCleanupResources_generator)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_generator))
